@@ -173,8 +173,10 @@ test_pipeline = val_pipeline
 
 data_root = 'data/aic'
 data = dict(
-    samples_per_gpu=24,
     workers_per_gpu=2,
+    train_dataloader=dict(samples_per_gpu=24),
+    val_dataloader=dict(samples_per_gpu=1),
+    test_dataloader=dict(samples_per_gpu=1),
     train=dict(
         type='BottomUpAicDataset',
         ann_file=f'{data_root}/annotations/aic_train.json',
@@ -197,6 +199,6 @@ data = dict(
         img_prefix=f'{data_root}/ai_challenger_keypoint_validation_20170911/'
         'keypoint_validation_images_20170911/',
         data_cfg=data_cfg,
-        pipeline=val_pipeline,
+        pipeline=test_pipeline,
         dataset_info={{_base_.dataset_info}}),
 )
