@@ -168,8 +168,10 @@ test_pipeline = val_pipeline
 
 data_root = 'data/mhp'
 data = dict(
-    samples_per_gpu=16,
     workers_per_gpu=2,
+    train_dataloader=dict(samples_per_gpu=16),
+    val_dataloader=dict(samples_per_gpu=1),
+    test_dataloader=dict(samples_per_gpu=1),
     train=dict(
         type='BottomUpMhpDataset',
         ann_file=f'{data_root}/annotations/mhp_train.json',
@@ -189,6 +191,6 @@ data = dict(
         ann_file=f'{data_root}/annotations/mhp_val.json',
         img_prefix=f'{data_root}/val/images/',
         data_cfg=data_cfg,
-        pipeline=val_pipeline,
+        pipeline=test_pipeline,
         dataset_info={{_base_.dataset_info}}),
 )
