@@ -40,7 +40,7 @@ channel_cfg = dict(
 # model settings
 model = dict(
     type='TopDown',
-    pretrained='mmcls://resnext152',
+    pretrained='mmcls://resnext152_32x4d',
     backbone=dict(type='ResNeXt', depth=152),
     keypoint_head=dict(
         type='TopdownHeatmapSimpleHead',
@@ -140,6 +140,6 @@ data = dict(
         ann_file=f'{data_root}/annotations/person_keypoints_val2017.json',
         img_prefix=f'{data_root}/val2017/',
         data_cfg=data_cfg,
-        pipeline=val_pipeline,
+        pipeline=test_pipeline,
         dataset_info={{_base_.dataset_info}}),
 )
