@@ -34,7 +34,7 @@ channel_cfg = dict(
 # model settings
 model = dict(
     type='TopDown',
-    pretrained='mmcls://resnext101',
+    pretrained='mmcls://resnext101_32x4d',
     backbone=dict(type='ResNeXt', depth=101),
     keypoint_head=dict(
         type='TopdownHeatmapSimpleHead',
