@@ -121,4 +121,5 @@ data = dict(
         ann_file=f'{data_root}/annotations/mpii_trb_val.json',
         img_prefix=f'{data_root}/images/',
         data_cfg=data_cfg,
-        pipeline=test_pipeline))
+        pipeline=test_pipeline,
+        dataset_info={{_base_.dataset_info}}))
