@@ -1,11 +1,13 @@
 # Copyright (c) OpenMMLab. All rights reserved.
 import os
+import warnings
 from argparse import ArgumentParser
 
 from xtcocotools.coco import COCO
 
 from mmpose.apis import (inference_top_down_pose_model, init_pose_model,
                          vis_pose_result)
+from mmpose.datasets import DatasetInfo
 
 
 def main():
@@ -58,6 +60,14 @@ def main():
         args.pose_config, args.pose_checkpoint, device=args.device.lower())
 
     dataset = pose_model.cfg.data['test']['type']
+    dataset_info = pose_model.cfg.data['test'].get('dataset_info', None)
+    if dataset_info is None:
+        warnings.warn(
+            'Please set `dataset_info` in the config.'
+            'Check https://github.com/open-mmlab/mmpose/pull/663 for details.',
+            DeprecationWarning)
+    else:
+        dataset_info = DatasetInfo(dataset_info)
 
     img_keys = list(coco.imgs.keys())
 
@@ -92,6 +102,7 @@ def main():
             bbox_thr=None,
             format='xywh',
             dataset=dataset,
+            dataset_info=dataset_info,
             return_heatmap=return_heatmap,
             outputs=output_layer_names)
 
@@ -106,6 +117,7 @@ def main():
             image_name,
             pose_results,
             dataset=dataset,
+            dataset_info=dataset_info,
             kpt_score_thr=args.kpt_thr,
             radius=args.radius,
             thickness=args.thickness,
