@@ -8,8 +8,10 @@ import numpy as np
 import torch
 from mmcv.parallel import collate, scatter
 from mmcv.runner import load_checkpoint
+from PIL import Image
 
 from mmpose.core.post_processing import oks_nms
+from mmpose.datasets.dataset_info import DatasetInfo
 from mmpose.datasets.pipelines import Compose
 from mmpose.models import build_posenet
 from mmpose.utils.hooks import OutputHook
@@ -38,7 +40,7 @@ def init_pose_model(config, checkpoint=None, device='cuda:0'):
     model = build_posenet(config.model)
     if checkpoint is not None:
         # load model checkpoint
-        load_checkpoint(model, checkpoint, map_location=device)
+        load_checkpoint(model, checkpoint, map_location='cpu')
     # save the config in the model for convenience
     model.cfg = config
     model.to(device)
@@ -154,8 +156,9 @@ def _inference_single_pose_model(model,
                                  return_heatmap=False):
     """Inference human bounding boxes.
 
-    num_bboxes: N
-    num_keypoints: K
+    Note:
+        - num_bboxes: N
+        - num_keypoints: K
 
     Args:
         model (nn.Module): The loaded pose model.
@@ -332,7 +335,7 @@ def _inference_single_pose_model(model,
 
 def inference_top_down_pose_model(model,
                                   img_or_path,
-                                  person_results,
+                                  person_results=None,
                                   bbox_thr=None,
                                   format='xywh',
                                   dataset='TopDownCocoDataset',
@@ -341,46 +344,58 @@ def inference_top_down_pose_model(model,
                                   outputs=None):
     """Inference a single image with a list of person bounding boxes.
 
-    num_people: P
-    num_keypoints: K
-    bbox height: H
-    bbox width: W
+    Note:
+        - num_people: P
+        - num_keypoints: K
+        - bbox height: H
+        - bbox width: W
 
     Args:
         model (nn.Module): The loaded pose model.
         img_or_path (str| np.ndarray): Image filename or loaded image.
-        person_results (List(dict)): the item in the dict may contain
-            'bbox' and/or 'track_id'.
-            'bbox' (4, ) or (5, ): The person bounding box, which contains
-            4 box coordinates (and score).
-            'track_id' (int): The unique id for each human instance.
-        bbox_thr: Threshold for bounding boxes. Only bboxes with higher scores
-            will be fed into the pose detector. If bbox_thr is None, ignore it.
-        format: bbox format ('xyxy' | 'xywh'). Default: 'xywh'.
-            'xyxy' means (left, top, right, bottom),
-            'xywh' means (left, top, width, height).
+        person_results (list(dict), optional): a list of detected persons that
+            contains ``bbox`` and/or ``track_id``:
+
+            - ``bbox`` (4, ) or (5, ): The person bounding box, which contains
+                4 box coordinates (and score).
+            - ``track_id`` (int): The unique id for each human instance. If
+                not provided, a dummy person result with a bbox covering
+                the entire image will be used. Default: None.
+        bbox_thr (float | None): Threshold for bounding boxes. Only bboxes
+            with higher scores will be fed into the pose detector.
+            If bbox_thr is None, all boxes will be used.
+        format (str): bbox format ('xyxy' | 'xywh'). Default: 'xywh'.
+
+            - `xyxy` means (left, top, right, bottom),
+            - `xywh` means (left, top, width, height).
         dataset (str): Dataset name, e.g. 'TopDownCocoDataset'.
             It is deprecated. Please use dataset_info instead.
         dataset_info (DatasetInfo): A class containing all dataset info.
         return_heatmap (bool) : Flag to return heatmap, default: False
         outputs (list(str) | tuple(str)) : Names of layers whose outputs
-            need to be returned, default: None
+            need to be returned. Default: None.
 
     Returns:
-        list[dict]: The bbox & pose info,
-            Each item in the list is a dictionary,
-            containing the bbox: (left, top, right, bottom, [score])
-            and the pose (ndarray[Kx3]): x, y, score
-        list[dict[np.ndarray[N, K, H, W] | torch.tensor[N, K, H, W]]]:
-            Output feature maps from layers specified in `outputs`.
+        tuple:
+        - pose_results (list[dict]): The bbox & pose info. \
+            Each item in the list is a dictionary, \
+            containing the bbox: (left, top, right, bottom, [score]) \
+            and the pose (ndarray[Kx3]): x, y, score.
+        - returned_outputs (list[dict[np.ndarray[N, K, H, W] | \
+            torch.Tensor[N, K, H, W]]]): \
+            Output feature maps from layers specified in `outputs`. \
             Includes 'heatmap' if `return_heatmap` is True.
     """
+    # get dataset info
+    if (dataset_info is None and hasattr(model, 'cfg')
+            and 'dataset_info' in model.cfg):
+        dataset_info = DatasetInfo(model.cfg.dataset_info)
     if dataset_info is None:
         warnings.warn(
             'dataset is deprecated.'
             'Please set `dataset_info` in the config.'
-            'Check https://github.com/open-mmlab/mmpose/pull/663 for details.',
-            DeprecationWarning)
+            'Check https://github.com/open-mmlab/mmpose/pull/663'
+            ' for details.', DeprecationWarning)
 
     # only two kinds of bbox format is supported.
     assert format in ['xyxy', 'xywh']
@@ -388,6 +403,14 @@ def inference_top_down_pose_model(model,
     pose_results = []
     returned_outputs = []
 
+    if person_results is None:
+        # create dummy person results
+        if isinstance(img_or_path, str):
+            width, height = Image.open(img_or_path).size
+        else:
+            height, width = img_or_path.shape[:2]
+        person_results = [{'bbox': np.array([0, 0, width, height])}]
+
     if len(person_results) == 0:
         return pose_results, returned_outputs
 
@@ -447,12 +470,13 @@ def inference_bottom_up_pose_model(model,
                                    pose_nms_thr=0.9,
                                    return_heatmap=False,
                                    outputs=None):
-    """Inference a single image.
+    """Inference a single image with a bottom-up pose model.
 
-    num_people: P
-    num_keypoints: K
-    bbox height: H
-    bbox width: W
+    Note:
+        - num_people: P
+        - num_keypoints: K
+        - bbox height: H
+        - bbox width: W
 
     Args:
         model (nn.Module): The loaded pose model.
@@ -466,14 +490,36 @@ def inference_bottom_up_pose_model(model,
             need to be returned, default: None.
 
     Returns:
-        list[ndarray]: The predicted pose info.
-            The length of the list is the number of people (P).
-            Each item in the list is a ndarray, containing each person's
-            pose (ndarray[Kx3]): x, y, score.
-        list[dict[np.ndarray[N, K, H, W] | torch.tensor[N, K, H, W]]]:
-            Output feature maps from layers specified in `outputs`.
+        tuple:
+        - pose_results (list[np.ndarray]): The predicted pose info. \
+            The length of the list is the number of people (P). \
+            Each item in the list is a ndarray, containing each \
+            person's pose (np.ndarray[Kx3]): x, y, score.
+        - returned_outputs (list[dict[np.ndarray[N, K, H, W] | \
+            torch.Tensor[N, K, H, W]]]): \
+            Output feature maps from layers specified in `outputs`. \
             Includes 'heatmap' if `return_heatmap` is True.
     """
+    # get dataset info
+    if (dataset_info is None and hasattr(model, 'cfg')
+            and 'dataset_info' in model.cfg):
+        dataset_info = DatasetInfo(model.cfg.dataset_info)
+
+    if dataset_info is not None:
+        dataset_name = dataset_info.dataset_name
+        flip_index = dataset_info.flip_index
+        sigmas = getattr(dataset_info, 'sigmas', None)
+    else:
+        warnings.warn(
+            'dataset is deprecated.'
+            'Please set `dataset_info` in the config.'
+            'Check https://github.com/open-mmlab/mmpose/pull/663 for details.',
+            DeprecationWarning)
+        assert (dataset == 'BottomUpCocoDataset')
+        dataset_name = dataset
+        flip_index = [0, 2, 1, 4, 3, 6, 5, 8, 7, 10, 9, 12, 11, 14, 13, 16, 15]
+        sigmas = None
+
     pose_results = []
     returned_outputs = []
 
@@ -486,25 +532,12 @@ def inference_bottom_up_pose_model(model,
                      ] + cfg.test_pipeline[1:]
     test_pipeline = Compose(test_pipeline)
 
-    if dataset_info is not None:
-        dataset_name = dataset_info.dataset_name
-        flip_index = dataset_info.flip_index
-    else:
-        warnings.warn(
-            'dataset is deprecated.'
-            'Please set `dataset_info` in the config.'
-            'Check https://github.com/open-mmlab/mmpose/pull/663 for details.',
-            DeprecationWarning)
-        assert (dataset == 'BottomUpCocoDataset')
-        dataset_name = dataset
-        flip_index = [0, 2, 1, 4, 3, 6, 5, 8, 7, 10, 9, 12, 11, 14, 13, 16, 15]
-
     # prepare data
     data = {
         'img_or_path': img_or_path,
         'dataset': dataset_name,
         'ann_info': {
-            'image_size': cfg.data_cfg['image_size'],
+            'image_size': np.array(cfg.data_cfg['image_size']),
             'num_joints': cfg.data_cfg['num_joints'],
             'flip_index': flip_index,
         }
@@ -543,7 +576,7 @@ def inference_bottom_up_pose_model(model,
             })
 
         # pose nms
-        keep = oks_nms(pose_results, pose_nms_thr, sigmas=None)
+        keep = oks_nms(pose_results, pose_nms_thr, sigmas)
         pose_results = [pose_results[_keep] for _keep in keep]
 
     return pose_results, returned_outputs
@@ -574,6 +607,12 @@ def vis_pose_result(model,
         show (bool):  Whether to show the image. Default True.
         out_file (str|None): The filename of the output visualization image.
     """
+
+    # get dataset info
+    if (dataset_info is None and hasattr(model, 'cfg')
+            and 'dataset_info' in model.cfg):
+        dataset_info = DatasetInfo(model.cfg.dataset_info)
+
     if dataset_info is not None:
         skeleton = dataset_info.skeleton
         pose_kpt_color = dataset_info.pose_kpt_color
@@ -813,6 +852,7 @@ def process_mmdet_results(mmdet_results, cat_id=1):
     Args:
         mmdet_results (list|tuple): mmdet results.
         cat_id (int): category id (default: 1 for human)
+
     Returns:
         person_results (list): a list of detected bounding boxes
     """
