@@ -4,9 +4,11 @@ from .interhand_3d import Interhand3D
 from .mesh import ParametricMesh
 from .multi_task import MultiTask
 from .pose_lifter import PoseLifter
+from .posewarper import PoseWarper
 from .top_down import TopDown
+from .voxelpose import VoxelPose
 
 __all__ = [
     'TopDown', 'AssociativeEmbedding', 'ParametricMesh', 'MultiTask',
-    'PoseLifter', 'Interhand3D'
+    'PoseLifter', 'Interhand3D', 'PoseWarper', 'VoxelPose'
 ]
