@@ -10,7 +10,7 @@ from ..builder import LOSSES
 
 @LOSSES.register_module()
 class SmoothL1Loss(nn.Module):
-    """SmoothL1Loss loss .
+    """SmoothL1Loss loss.
 
     Args:
         use_target_weight (bool): Option to use weighted MSE loss.
@@ -28,9 +28,9 @@ class SmoothL1Loss(nn.Module):
         """Forward function.
 
         Note:
-            batch_size: N
-            num_keypoints: K
-            dimension of keypoints: D (D=2 or D=3)
+            - batch_size: N
+            - num_keypoints: K
+            - dimension of keypoints: D (D=2 or D=3)
 
         Args:
             output (torch.Tensor[N, K, D]): Output regression.
@@ -50,11 +50,12 @@ class SmoothL1Loss(nn.Module):
 
 @LOSSES.register_module()
 class WingLoss(nn.Module):
-    """Wing Loss 'Wing Loss for Robust Facial Landmark Localisation with
-    Convolutional Neural Networks' Feng et al. CVPR'2018.
+    """Wing Loss. paper ref: 'Wing Loss for Robust Facial Landmark Localisation
+    with Convolutional Neural Networks' Feng et al. CVPR'2018.
 
     Args:
-        omega (float), epsilon (float) are hyper-parameters.
+        omega (float): Also referred to as width.
+        epsilon (float): Also referred to as curvature.
         use_target_weight (bool): Option to use weighted MSE loss.
             Different joint types may have different target weights.
         loss_weight (float): Weight of the loss. Default: 1.0.
@@ -75,6 +76,84 @@ class WingLoss(nn.Module):
         # and nonlinear parts
         self.C = self.omega * (1.0 - math.log(1.0 + self.omega / self.epsilon))
 
+    def criterion(self, pred, target):
+        """Criterion of wingloss.
+
+        Note:
+            - batch_size: N
+            - num_keypoints: K
+            - dimension of keypoints: D (D=2 or D=3)
+
+        Args:
+            pred (torch.Tensor[N, K, D]): Output regression.
+            target (torch.Tensor[N, K, D]): Target regression.
+        """
+        delta = (target - pred).abs()
+        losses = torch.where(
+            delta < self.omega,
+            self.omega * torch.log(1.0 + delta / self.epsilon), delta - self.C)
+        return torch.mean(torch.sum(losses, dim=[1, 2]), dim=0)
+
+    def forward(self, output, target, target_weight=None):
+        """Forward function.
+
+        Note:
+            - batch_size: N
+            - num_keypoints: K
+            - dimension of keypoints: D (D=2 or D=3)
+
+        Args:
+            output (torch.Tensor[N, K, D]): Output regression.
+            target (torch.Tensor[N, K, D]): Target regression.
+            target_weight (torch.Tensor[N,K,D]):
+                Weights across different joint types.
+        """
+        if self.use_target_weight:
+            assert target_weight is not None
+            loss = self.criterion(output * target_weight,
+                                  target * target_weight)
+        else:
+            loss = self.criterion(output, target)
+
+        return loss * self.loss_weight
+
+
+@LOSSES.register_module()
+class SoftWingLoss(nn.Module):
+    """Soft Wing Loss 'Structure-Coherent Deep Feature Learning for Robust Face
+    Alignment' Lin et al. TIP'2021.
+
+    loss =
+        1. |x|                           , if |x| < omega1
+        2. omega2*ln(1+|x|/epsilon) + B, if |x| >= omega1
+
+    Args:
+        omega1 (float): The first threshold.
+        omega2 (float): The second threshold.
+        epsilon (float): Also referred to as curvature.
+        use_target_weight (bool): Option to use weighted MSE loss.
+            Different joint types may have different target weights.
+        loss_weight (float): Weight of the loss. Default: 1.0.
+    """
+
+    def __init__(self,
+                 omega1=2.0,
+                 omega2=20.0,
+                 epsilon=0.5,
+                 use_target_weight=False,
+                 loss_weight=1.):
+        super().__init__()
+        self.omega1 = omega1
+        self.omega2 = omega2
+        self.epsilon = epsilon
+        self.use_target_weight = use_target_weight
+        self.loss_weight = loss_weight
+
+        # constant that smoothly links the piecewise-defined linear
+        # and nonlinear parts
+        self.B = self.omega1 - self.omega2 * math.log(1.0 + self.omega1 /
+                                                      self.epsilon)
+
     def criterion(self, pred, target):
         """Criterion of wingloss.
 
@@ -89,8 +168,8 @@ class WingLoss(nn.Module):
         """
         delta = (target - pred).abs()
         losses = torch.where(
-            delta < self.omega,
-            self.omega * torch.log(1.0 + delta / self.epsilon), delta - self.C)
+            delta < self.omega1, delta,
+            self.omega2 * torch.log(1.0 + delta / self.epsilon) + self.B)
         return torch.mean(torch.sum(losses, dim=[1, 2]), dim=0)
 
     def forward(self, output, target, target_weight=None):
@@ -136,14 +215,14 @@ class MPJPELoss(nn.Module):
         """Forward function.
 
         Note:
-            batch_size: N
-            num_keypoints: K
-            dimension of keypoints: D (D=2 or D=3)
+            - batch_size: N
+            - num_keypoints: K
+            - dimension of keypoints: D (D=2 or D=3)
 
         Args:
             output (torch.Tensor[N, K, D]): Output regression.
             target (torch.Tensor[N, K, D]): Target regression.
-            target_weight (torch.Tensor[N, K, D]):
+            target_weight (torch.Tensor[N,K,D]):
                 Weights across different joint types.
         """
 
@@ -171,8 +250,8 @@ class L1Loss(nn.Module):
         """Forward function.
 
         Note:
-            batch_size: N
-            num_keypoints: K
+            - batch_size: N
+            - num_keypoints: K
 
         Args:
             output (torch.Tensor[N, K, 2]): Output regression.
@@ -204,8 +283,8 @@ class MSELoss(nn.Module):
         """Forward function.
 
         Note:
-            batch_size: N
-            num_keypoints: K
+            - batch_size: N
+            - num_keypoints: K
 
         Args:
             output (torch.Tensor[N, K, 2]): Output regression.
@@ -249,9 +328,9 @@ class BoneLoss(nn.Module):
         """Forward function.
 
         Note:
-            batch_size: N
-            num_keypoints: K
-            dimension of keypoints: D (D=2 or D=3)
+            - batch_size: N
+            - num_keypoints: K
+            - dimension of keypoints: D (D=2 or D=3)
 
         Args:
             output (torch.Tensor[N, K, D]): Output regression.
@@ -282,8 +361,8 @@ class SemiSupervisionLoss(nn.Module):
     """Semi-supervision loss for unlabeled data. It is composed of projection
     loss and bone loss.
 
-     Paper ref: `3D human pose estimation in video with temporal convolutions
-     and semi-supervised training` Dario Pavllo et al. CVPR'2019.
+    Paper ref: `3D human pose estimation in video with temporal convolutions
+    and semi-supervised training` Dario Pavllo et al. CVPR'2019.
 
     Args:
         joint_parents (list): Indices of each joint's parent joint.
